@@ -15,6 +15,7 @@ import os
 import sys
 import inspect
 import traceback
+import collections
 from pyramid.response import Response
 from sqlalchemy import create_engine
 
@@ -38,14 +39,29 @@ class App(object):
         self.schema_name = None
         self.developer_id = None
         self.step_groups = []
-        self.app_folder_path = os.path.split(os.path.realpath(inspect.getfile(type(self))))[0]
+        self.app_folder_path = None  # Needs to be set dynamically after app created. This is to avoid params in constructor.
         self._init_step_groups()
+
+    def init_db_engine(self):
+        """
+        Initialise database engine connection string. Is dynamic to enable for SQLite and PSQL connections
+        Note: Must be called after self.app_folder_path is set.
+
+        This has to be dynamic as otherwise it would require params to App.__init__ to be set. This would
+        greatly complicate App definition for users.
+
+        :raise AttributeError: self.app_folder_path is not set prior to function call.
+        """
+        if self.app_folder_path is None:
+            raise AttributeError('self.app_folder_path must be set before App.init_db_engine is called.')
+
         if App.overridden_global_sqla_engine:
             self.engine = create_engine(App.overridden_global_sqla_engine)
         else:
             engine_path = os.path.join(self.app_folder_path, self.url_name + ".db")
             self.engine = create_engine("sqlite:///" + engine_path)
 
+
     def _init_step_groups(self):
         """Overide this to insert step groups before or after gui stepgroups"""
         self._add_gui_stepgroups_with_steps()
@@ -123,23 +139,31 @@ class App(object):
                 widgets.extend(step.widgets)
         return widgets
 
-    def get_tables_mapped_to_classes_for_app(self):
+    def get_dependency_ordered_dict_of_tables_mapped_to_classes_for_app(self):
+        """
+        :returns: ordered dict of sqlalchemy.sql.schema.Table: to SQL ORM Class
+        """
         orm_classes = []
         for _, class_type in inspect.getmembers(sys.modules[self.__module__], inspect.isclass):
-            if class_type.__module__ == str(sys.modules[self.__module__].__name__):
-                if ORMBase in inspect.getmro(class_type):
+            if ORMBase in inspect.getmro(class_type):
+                is_tropofy_framework_class = class_type.__module__.split('.')[0] == 'tropofy'
+                if not is_tropofy_framework_class:
                     orm_classes.append(class_type)
 
-        mapping = {}
-        for class_ in orm_classes:
-            table_name = class_.__tablename__ if self.schema_name else class_.__tablename__
-            tables = TropofyDbMetaData.get_dependency_sorted_tables([table_name])
-            if tables:
-                mapping[tables[0]] = class_
-        return mapping
+        table_name_and_schema_to_orm_class = dict(
+            ((TropofyDbMetaData.TableNameAndSchema(class_.__tablename__, self.schema_name), class_) for class_ in orm_classes)
+        )
+        dependency_sorted_tables = TropofyDbMetaData.get_dependency_sorted_tables(table_name_and_schema_to_orm_class.keys())
+
+        dependency_ordered_dict_of_tables_mapped_to_classes = collections.OrderedDict()
+        for table in dependency_sorted_tables:
+            class_ = table_name_and_schema_to_orm_class[TropofyDbMetaData.TableNameAndSchema(table.name, self.schema_name)]
+            dependency_ordered_dict_of_tables_mapped_to_classes[table] = class_
+
+        return dependency_ordered_dict_of_tables_mapped_to_classes
 
     def get_orm_tables(self):
-        return self.get_tables_mapped_to_classes_for_app().keys()
+        return self.get_dependency_ordered_dict_of_tables_mapped_to_classes_for_app().keys()
 
     def get_data_set_as_excel_wb_string_repr(self, data_set):
         return read_write_xl.create_excel_string_repr(data_set)
