@@ -238,3 +238,8 @@ def check_response_for_success(response):
 @view_config(route_name='favicon')
 def favicon(response):
     return Response()
+
+
+@view_config(route_name='healthcheck')
+def healthcheck(response):
+    return Response()
\ No newline at end of file
