@@ -87,7 +87,7 @@ class Form(Widget):
 
         def _process_options(self, options):
             """Convert to list of :class:`tropofy.widgets.Form.Element.Option` from old option formats:
-                
+
             For backward compatibility (<= 0.36.3). Enables options to be input in multiple formats.
             strings or list of dictionaries - {value: <value>, text: <text>}, where <text> is the text displayed in the select and <value> the value submitted with the form.
 
@@ -114,7 +114,7 @@ class Form(Widget):
             :type value: jsonifiable type (usually str or int)
             :param text: (Optional) Option text displayed in select list. Default to value if not provided.
             :type text: str
-            :param dependent_option_lists: 
+            :param dependent_option_lists:
             :type dependent_option_lists: list of dicts of form {name: <option list name> options: <list of :class:`tropofy.widgets.Form.Element.Option`>
             """
             def __init__(self, value, text=None, dependent_option_lists=None):
@@ -132,7 +132,6 @@ class Form(Widget):
                     } for name, options in self.dependent_option_lists.iteritems()]
                 }
 
-
     def get_type(self):
         return "FormWidget"
 
@@ -170,7 +169,7 @@ class Form(Widget):
                - name (str): Must match the name of a corresponding :class:`tropofy.widgets.Form.Element`.
                - success (optional bool): defaults to true. Indicates single form element submit success or failure.
                - message (optional str): default to null. Response message for single form element submit.
-               
+
         'name', 'success', 'message', 'value'
         :rtype: dict
         """  # Todo: Probably add another element in returns for 'edited_row' so can integrate with Grid.
@@ -262,8 +261,8 @@ class ParameterForm(Form):
     :param parameter_names_filter: (Optional) List of parameter names to display on form. If none are specified, default is to display all parameters.
     :type parameter_names_filter: list
     """
-    def __init__(self, title='Parameters', parameter_names_filter = []):
-        self.parameter_names_filter = parameter_names_filter
+    def __init__(self, title='Parameters', parameter_names_filter=None):
+        self.parameter_names_filter = parameter_names_filter if parameter_names_filter is not None else []
         self.title = title
 
     def get_form_elements(self, data_set):
@@ -271,7 +270,7 @@ class ParameterForm(Form):
         for param in data_set.app.get_parameters():
             if not self.parameter_names_filter or param.name in self.parameter_names_filter:
                 value = data_set.get_param(param.name)
-    
+
                 options = param.options
                 if param.allowed_type is bool:
                     options = [
@@ -295,7 +294,7 @@ class ParameterForm(Form):
     def process_data(self, data, data_set):
         results = []
         for name, value in data.iteritems():
-            try:        
+            try:
                 data_set.set_param(name=name, value=value)
             except (ValidationException, IntegrityError) as e:
                 results.append({
@@ -305,6 +304,7 @@ class ParameterForm(Form):
                 })
         return {'results': results}
 
+
 class Filter(Form):
     """An implementation of :class:`tropofy.widgets.Form` specifically designed to act as a filter for other widgets.
 
@@ -348,7 +348,7 @@ class Filter(Form):
 
     def process_data(self, data, data_set):
         for name, value in data.items():
-            data_set.set_var(self._get_var_name(name), value)    
+            data_set.set_var(self._get_var_name(name), value)
 
     def _get_var_name(self, element_name):
         return 'filter_%s_%s' % (self.id, element_name)
@@ -375,4 +375,4 @@ class Filter(Form):
         self.process_data(
             data=defaults,
             data_set=data_set
-        )
\ No newline at end of file
+        )
