@@ -1,11 +1,11 @@
-'''
+"""
 Authors: www.tropofy.com and www.gurobi.com
 
 Copyright 2013 Tropofy Pty Ltd, all rights reserved.
 Copyright 2013, Gurobi Optimization, Inc.
 
 This source file (where not indicated as under the copyright of Gurobi)
-is part of Tropofy and govered by the Tropofy terms of service
+is part of Tropofy and governed by the Tropofy terms of service
 available at: http://www.tropofy.com/terms_of_service.html
 
 Parts of the formulation provided by Gurobi have been modified.
@@ -16,9 +16,9 @@ Used with permission.
 This source file is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
-'''
+"""
 
-import gurobipy # Note eclipse has problems importing quicksum so we dont import selectively
+import gurobipy # Note eclipse has problems importing quicksum so we don't import selectively
 from sqlalchemy.types import Text, Float
 from sqlalchemy.schema import Column, ForeignKeyConstraint, UniqueConstraint
 from sqlalchemy.orm import relationship
